@@ -10,7 +10,7 @@ class ContactSchema(CamelCaseSchema):
   carrier_id = fields.UUID(allow_none=True)
   first_name = fields.String()
   last_name = fields.String(allow_none=True)
-  phone = fields.String()
+  phone = fields.String(allow_none=True)
   email_address = fields.Email()
   mobile = fields.String(allow_none=True)
   primary_contact = fields.Boolean(allow_none=True, missgin=False)
