@@ -1,6 +1,4 @@
 import googlemaps
-import json
-import requests
 
 from cc_py_commons.config.env import app_config
 from cc_py_commons.utils.redis import location_db_conn, distance_db_conn, timezone_db_conn
@@ -113,6 +111,88 @@ def __get_google_location(city, state, zipcode, logger):
     def __parse_response(response):
       if not response or len(response) == 0:
         return None
+      ''' 
+        Sample response of Google Maps API for address: Cincinati, OH, 45204
+        {
+            "address_components": [
+                {
+                    "long_name": "45204",
+                    "short_name": "45204",
+                    "types": [
+                        "postal_code"
+                    ]
+                },
+                {
+                    "long_name": "Cincinnati",
+                    "short_name": "Cincinnati",
+                    "types": [
+                        "locality",
+                        "political"
+                    ]
+                },
+                {
+                    "long_name": "Hamilton County",
+                    "short_name": "Hamilton County",
+                    "types": [
+                        "administrative_area_level_2",
+                        "political"
+                    ]
+                },
+                {
+                    "long_name": "Ohio",
+                    "short_name": "OH",
+                    "types": [
+                        "administrative_area_level_1",
+                        "political"
+                    ]
+                },
+                {
+                    "long_name": "United States",
+                    "short_name": "US",
+                    "types": [
+                        "country",
+                        "political"
+                    ]
+                }
+            ],
+            "formatted_address": "Cincinnati, OH 45204, USA",
+            "geometry": {
+                "bounds": {
+                    "northeast": {
+                        "lat": 39.1251898,
+                        "lng": -84.539683
+                    },
+                    "southwest": {
+                        "lat": 39.073286,
+                        "lng": -84.62870989999999
+                    }
+                },
+                "location": {
+                    "lat": 39.0930395,
+                    "lng": -84.56676650000001
+                },
+                "location_type": "APPROXIMATE",
+                "viewport": {
+                    "northeast": {
+                        "lat": 39.1251898,
+                        "lng": -84.539683
+                    },
+                    "southwest": {
+                        "lat": 39.073286,
+                        "lng": -84.62870989999999
+                    }
+                }
+            },
+            "place_id": "ChIJjYEP0hK2QYgRTJoYykoQeqw",
+            "postcode_localities": [
+                "Cincinnati",
+                "Queen City Square"
+            ],
+            "types": [
+                "postal_code"
+            ]
+        }
+      '''
       components = response[0]['address_components']
       types = response[0]['types']
       location = response[0]['geometry']['location']
@@ -123,13 +203,14 @@ def __get_google_location(city, state, zipcode, logger):
       data['lng'] = location['lng']
 
       # when checking the response for a zipcode verify the city name is in the list of localities
-      if 'postal_code' in types and postcode_localities:
+      if 'postal_code' in types and postcode_localities and city:
         matches = [l for l in components if (
                     'postal_localities' in l.get('types') and
                     (l.short_name.lower() == city.lower() or l.long_name.lower() == city.lower())
         )]
+        city_present_in_postcode_localities = (city in postcode_localities)
 
-        if not matches:
+        if not matches and not city_present_in_postcode_localities:
           return None
 
       for component in components:
